@@ -20,7 +20,7 @@ our $VERSION = '0.0.1';
 
     use Toader::Render::Entry::backends::html;
     
-    my $renderer=Toader::Render::Directory::backends::html->new({ toader=>$toader, obj=>$directoryObj });
+    my $renderer=Toader::Render::Directory::backends::html->new({ toader=>$toader, obj=>$entryObj });
     my $rendered;
     if ( $renderer->error ){
         warn( 'Error:'.$renderer->error.': '.$renderer->errorString );
@@ -154,7 +154,9 @@ sub render{
 		$self->warn;
 		return undef;
 	}
+
 	
+
 	return $torender;
 }
 
@@ -229,7 +231,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011. Zane C. Bowers-Hadley.
+Copyright 2012. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
